package Task::BeLike::CSSON { }
$Task::BeLike::CSSON::VERSION = '0.0003';
1;
__END__

=encoding utf-8

=head1 NAME

Task::BeLike::CSSON - Stuff I need

=head1 SYNOPSIS

    # or equivalent
    $ sudo apt-get install libssl-dev
    $ sudo apt-get install libgd2-xpm-dev
    $ sudo apt-get install ncurses-dev
    $ sudo apt-get install libreadline6 libreadline6-dev

    $ git config --global user.email '...'
    $ git config --global user.name '...'

    # install mysql/mariadb, and
    $ export DBD_TESTUSER=...
    $ export DBD_TESTPASSWORD=...
    $ export DBD_TESTDB=...

    $ cpanm Class::Accessor
    $ cpanm Devel::Declare::MethodInstaller::Simple
    $ cpanm Compiler::Lexer
    $ cpanm Task::BeLike::CSSON

=head1 TASK CONTENTS

See cpanfile.

=head1 AUTHOR

Erik Carlsson E<lt>info@code301.comE<gt>

=head1 COPYRIGHT

Copyright 2014- Erik Carlsson

=head1 LICENSE

This library is free software; you can redistribute it and/or modify
it under the same terms as Perl itself.

=head1 SEE ALSO

=cut
